diff --git a/examples/html-demo/src/main.ts b/examples/html-demo/src/main.ts
index c32dcd8d..022fe7a9 100644
--- a/examples/html-demo/src/main.ts
+++ b/examples/html-demo/src/main.ts
@@ -3,18 +3,18 @@ import '@videojs/html/skins/minimal';
document.body.innerHTML = /* html */ `
-
+
-
-
+
-
+
-
+
`;
diff --git a/examples/html-eject-minimal/index.html b/examples/html-eject-minimal/index.html
index 4f737bb3..515e5915 100644
--- a/examples/html-eject-minimal/index.html
+++ b/examples/html-eject-minimal/index.html
@@ -29,7 +29,7 @@
padding: 1rem;
"
>
-
+
diff --git a/examples/html-eject-frosted/src/main.ts b/examples/html-eject-frosted/src/main.ts
index 23a78a28..49aada20 100644
--- a/examples/html-eject-frosted/src/main.ts
+++ b/examples/html-eject-frosted/src/main.ts
@@ -1,7 +1,7 @@
import './frosted.css';
import '@videojs/html/icons';
-// be sure to import media-provider first
-import '@videojs/html/define/media-provider';
+// be sure to import video-provider first
+import '@videojs/html/define/video-provider';
import '@videojs/html/define/media-container';
import '@videojs/html/define/media-play-button';
import '@videojs/html/define/media-mute-button';